neo_event

Attribute Macro neo_event 

#[neo_event]
Neo N3 Event macro

This macro generates the necessary boilerplate for a Neo N3 contract event.

Example

#[neo_event]
pub struct TransferEvent {
    pub from: NeoByteString,
    pub to: NeoByteString,
    pub amount: NeoInteger,
}

The macro generates:

  • An emit() method that notifies the runtime with the event data
  • Manifest metadata describing the event parameters