pub fn struct_entry(key: NeoByteString, value: NeoByteString) -> NeoValueExpand description
Creates a NeoStruct entry with key and value fields.
This is useful for returning storage entries from contract methods.
pub fn struct_entry(key: NeoByteString, value: NeoByteString) -> NeoValueCreates a NeoStruct entry with key and value fields.
This is useful for returning storage entries from contract methods.