pub fn storage_struct(key: &NeoByteString, value: &NeoByteString) -> NeoValueExpand description
Creates a storage entry struct with key and value fields.
This is equivalent to crate::storage::struct_entry.
pub fn storage_struct(key: &NeoByteString, value: &NeoByteString) -> NeoValueCreates a storage entry struct with key and value fields.
This is equivalent to crate::storage::struct_entry.