Neo N3 Prelude - commonly used items
Re-exports
pub use crate::serde;
Macros
- neo_
manifest_ overlay - Neo N3 Manifest Overlay macro
- neo_
permission - Declare manifest permissions and embed them as a custom section.
- neo_
safe_ methods - Declare safe methods for the contract manifest.
- neo_
supported_ standards - Declare supported standards for the contract manifest.
- neo_
trusts - Declare trusted contracts for the contract manifest.
Structs
- NeoArray
- Neo N3 Array type
- NeoBoolean
- Neo N3 Boolean type
- NeoByte
String - Neo N3 ByteString type
- NeoContractABI
- Neo N3 Contract ABI
- NeoContract
Event - Neo N3 Contract Event
- NeoContract
Manifest - Neo N3 Contract Manifest
- NeoContract
Method - Neo N3 Contract Method
- NeoContract
Parameter - Neo N3 Contract Parameter
- NeoContract
Permission - Neo N3 Contract Permission
- NeoContract
Runtime - Minimal representation of contract management utilities used in tests.
- NeoCrypto
- Deterministic crypto helpers for tests and examples.
- NeoInteger
- Neo N3 Integer type (arbitrary precision)
- NeoIterator
- Neo N3 Iterator type
- NeoJSON
- Minimal JSON helpers to support tests.
- NeoMap
- Neo N3 Map type
- NeoRuntime
- Direct wrappers for the canonical System.Runtime syscalls.
- NeoRuntime
Context - Lightweight view of the runtime context.
- NeoStorage
- Storage convenience helpers built on top of the syscall layer.
- NeoStorage
Context - Neo N3 Storage Context type
- NeoString
- Neo N3 String type
- NeoStruct
- Neo N3 Struct type
Enums
Traits
- NeoContract
- Neo N3 Contract trait
- NeoContract
Entry - Neo N3 Contract Entry Point
- NeoContract
Method Trait - Neo N3 Contract Method trait
- NeoContract
Trait - Neo N3 Contract trait
Type Aliases
- NeoResult
- Neo N3 Result type
Attribute Macros
- neo_
contract - Neo N3 Contract macro
- neo_
entry - Neo N3 Entry Point macro
- neo_
event - Neo N3 Event macro
- neo_
method - Neo N3 Method macro
- neo_
safe - Mark a single exported function as safe in the manifest.