Module prelude

Module prelude 

Neo N3 Prelude - commonly used items

Re-exports

pub use crate::serde;
pub use crate::native_contracts::*;
pub use crate::standards::*;

Macros

neo_manifest_overlay
Neo N3 Manifest Overlay macro
neo_permission
Declare manifest permissions and embed them as a custom section.
neo_safe_methods
Declare safe methods for the contract manifest.
neo_supported_standards
Declare supported standards for the contract manifest.
neo_trusts
Declare trusted contracts for the contract manifest.

Structs

Hash160
A 20-byte script hash used to identify accounts and contracts on Neo N3.
Hash256
A 32-byte hash used for transaction and block identifiers on Neo N3.
NeoArray
Neo N3 Array type
NeoBoolean
Neo N3 Boolean type
NeoByteString
Neo N3 ByteString type
NeoContractABI
Neo N3 Contract ABI
NeoContractEvent
Neo N3 Contract Event
NeoContractManifest
Neo N3 Contract Manifest
NeoContractMethod
Neo N3 Contract Method
NeoContractParameter
Neo N3 Contract Parameter
NeoContractPermission
Neo N3 Contract Permission
NeoContractRuntime
Neo N3 contract management operations.
NeoCrypto
Crypto helpers for Neo N3 smart contracts.
NeoInteger
Neo N3 Integer type (arbitrary precision)
NeoIterator
Neo N3 Iterator type
NeoJSON
Minimal JSON helpers to support tests.
NeoMap
Neo N3 Map type
NeoRuntime
Direct wrappers for the canonical System.Runtime syscalls.
NeoRuntimeContext
Lightweight view of the runtime context.
NeoStorage
Storage convenience helpers built on top of the syscall layer.
NeoStorageContext
Neo N3 Storage Context type
NeoString
Neo N3 String type
NeoStruct
Neo N3 Struct type
RawKeyBuilder
Fixed-capacity stack key builder for RawStorage keys.
RawStorage
Heap-free storage facade that operates on &[u8] slices.

Enums

NeoError
Neo N3 Error type
NeoValue
Neo N3 Value type (union of all Neo types)
RawStorageGet
Outcome of RawStorage::get_into.

Traits

NeoContract
Neo N3 Contract trait
NeoContractEntry
Neo N3 Contract Entry Point
NeoContractMethodTrait
Neo N3 Contract Method trait

Type Aliases

NeoResult
Neo N3 Result type

Attribute Macros

neo_contract
Neo N3 Contract macro
neo_entry
Neo N3 Entry Point macro
neo_event
Neo N3 Event macro
neo_method
Neo N3 Method macro
neo_safe
Mark a single exported function as safe in the manifest.