pub struct NeoMap<K, V> { /* private fields */ }Expand description
Neo N3 Map type
Implementations
Sourceimpl<K, V> NeoMap<K, V>
impl<K, V> NeoMap<K, V>
pub fn new() -> NeoMap<K, V>
pub fn insert(&mut self, key: K, value: V) -> Option<V>where
K: PartialEq,
Sourcepub fn get(&self, key: &K) -> Option<&V>where
K: PartialEq,
pub fn get(&self, key: &K) -> Option<&V>where
K: PartialEq,
Gets a reference to the value associated with the given key.
Performance
This operation is O(n) as it performs a linear search. Consider using a HashMap for O(1) lookups if performance is critical.
Sourcepub fn get_mut(&mut self, key: &K) -> Option<&mut V>where
K: PartialEq,
pub fn get_mut(&mut self, key: &K) -> Option<&mut V>where
K: PartialEq,
Gets a mutable reference to the value associated with the given key.
Performance
This operation is O(n) as it performs a linear search.
Sourcepub fn remove(&mut self, key: &K) -> Option<V>where
K: PartialEq,
pub fn remove(&mut self, key: &K) -> Option<V>where
K: PartialEq,
Removes the key-value pair associated with the given key.
Performance
This operation is O(n) due to the element removal.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn iter(&self) -> impl Iterator<Item = (&K, &V)>