storage_struct

Function storage_struct 

pub fn storage_struct(key: &NeoByteString, value: &NeoByteString) -> NeoValue
Creates a storage entry struct with key and value fields.

This is a convenience function for creating the standard storage entry format used by Neo N3 storage find operations.