pub fn storage_struct(key: &NeoByteString, value: &NeoByteString) -> NeoValueExpand description
Creates a storage entry struct with key and value fields.
This is a convenience function for creating the standard storage entry format used by Neo N3 storage find operations.